==> lumina-1.3.0_p1.tar.gz: lumina-1.3.0-p1/src-qt5/desktop-utils/lumina-screenshot/i18n/l-screenshot_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ImageEditor</name>
    <message>
        <location filename="../ImageEditor.cpp" line="14"/>
        <source>Zoom In</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location filename="../ImageEditor.cpp" line="15"/>
        <source>Zoom Out</source>
        <translation>Уменьшить</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="529"/>
        <source>Take Screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="422"/>
        <source>Include Borders</source>
        <translation>Включить границы</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="540"/>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>Resize</source>
        <translation>Изменить размер</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="20"/>
        <source>Lumina Screenshot</source>
        <translation>Lumina снимок экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="87"/>
        <source>Open screenshot with an application</source>
        <translation>Открыть скриншот с помощью приложения</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="103"/>
        <source>Copy screenshot to clipboard</source>
        <translation>Копировать скриншот в буфер обмена</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="106"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="109"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="135"/>
        <source>Resize screenshot to selection</source>
        <translation>Изменить размер скриншота до выделения</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="157"/>
        <source>Crop screenshot to selection</source>
        <translation>Обрезать скриншот до выделения</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="160"/>
        <source>&amp;Crop</source>
        <translation>Обрезать[&amp;C]</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="293"/>
        <source>Screen Capture Settings</source>
        <translation>Настройки захвата экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="341"/>
        <source> Sec Delay</source>
        <translation> Задержка (сек)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Select Area</source>
        <translation>Выберите область</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="445"/>
        <source>General Settings</source>
        <translation>Общие настройки</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="466"/>
        <source>Show popup warnings about unsaved screenshots</source>
        <translation>Показывать всплывающие предупреждения о несохраненных скриншотах</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="499"/>
        <source>toolBar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="526"/>
        <source>Capture</source>
        <translation>Захват</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="532"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="556"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="559"/>
        <source>Close Application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="562"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="328"/>
        <source>Entire Session</source>
        <translation>Вся сессия</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="409"/>
        <source>Single Window</source>
        <translation>Одно окно</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="370"/>
        <source>Single Screen</source>
        <translation>Один экран</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="39"/>
        <source>View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="40"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>Could not save screenshot</source>
        <translation>Не удалось сохранить снимок экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>The screenshot could not be saved. Please check directory permissions or pick a different directory</source>
        <translation>Снимок экрана не может быть сохранен. Пожалуйста, проверьте права доступа для каталога или выберите другой каталог</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>Save Screenshot</source>
        <translation>Сохранить Снимок</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="322"/>
        <source>Unsaved Screenshot</source>
        <translation>Несохраненный скриншот</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="323"/>
        <source>The current screenshot has not been saved yet. Do you want to save or discard your changes?</source>
        <translation>Текущий кадр не был сохранен. Вы хотите сохранить или отменить изменения?</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="543"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="551"/>
        <source>Quick Save</source>
        <translation>Быстрое сохранение</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>PNG Files (*.png);;AllFiles (*)</source>
        <translation>PNG Файлы (*.png);;Все Файлы (*)</translation>
    </message>
</context>
</TS>

==> lumina-1.4.0_p1.tar.gz: lumina-1.4.0-p1/src-qt5/desktop-utils/lumina-screenshot/i18n/l-screenshot_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ImageEditor</name>
    <message>
        <location filename="../ImageEditor.cpp" line="14"/>
        <source>Zoom In</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <location filename="../ImageEditor.cpp" line="15"/>
        <source>Zoom Out</source>
        <translation>Уменьшить</translation>
    </message>
</context>
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="529"/>
        <source>Take Screenshot</source>
        <translation>Сделать снимок экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="422"/>
        <source>Include Borders</source>
        <translation>Включить границы</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="540"/>
        <source>Save As</source>
        <translation>Сохранить как</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="138"/>
        <source>Resize</source>
        <translation>Изменить размер</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="20"/>
        <source>Lumina Screenshot</source>
        <translation>Lumina снимок экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="87"/>
        <source>Open screenshot with an application</source>
        <translation>Открыть скриншот с помощью приложения</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="90"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="103"/>
        <source>Copy screenshot to clipboard</source>
        <translation>Копировать скриншот в буфер обмена</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="106"/>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="109"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="135"/>
        <source>Resize screenshot to selection</source>
        <translation>Изменить размер скриншота до выделения</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="157"/>
        <source>Crop screenshot to selection</source>
        <translation>Обрезать скриншот до выделения</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="160"/>
        <source>&amp;Crop</source>
        <translation>Обрезать[&amp;C]</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="293"/>
        <source>Screen Capture Settings</source>
        <translation>Настройки захвата экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="341"/>
        <source> Sec Delay</source>
        <translation> Задержка (сек)</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="433"/>
        <source>Select Area</source>
        <translation>Выберите область</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="445"/>
        <source>General Settings</source>
        <translation>Общие настройки</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="466"/>
        <source>Show popup warnings about unsaved screenshots</source>
        <translation>Показывать всплывающие предупреждения о несохраненных скриншотах</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="526"/>
        <source>Capture</source>
        <translation>Захват</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="532"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="556"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="559"/>
        <source>Close Application</source>
        <translation>Закрыть приложение</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="562"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="328"/>
        <source>Entire Session</source>
        <translation>Вся сессия</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="409"/>
        <source>Single Window</source>
        <translation>Одно окно</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="370"/>
        <source>Single Screen</source>
        <translation>Один экран</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="39"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="40"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>Could not save screenshot</source>
        <translation>Не удалось сохранить снимок экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="103"/>
        <source>The screenshot could not be saved. Please check directory permissions or pick a different directory</source>
        <translation>Снимок экрана не может быть сохранен. Пожалуйста, проверьте права доступа для каталога или выберите другой каталог</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>Save Screenshot</source>
        <translation>Сохранить Снимок Экрана</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="325"/>
        <source>Unsaved Screenshot</source>
        <translation>Несохраненный скриншот</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="326"/>
        <source>The current screenshot has not been saved yet. Do you want to save or discard your changes?</source>
        <translation>Текущий кадр не был сохранен. Вы хотите сохранить или отменить изменения?</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="329"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="330"/>
        <source>Discard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="331"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="543"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="551"/>
        <source>Quick Save</source>
        <translation>Быстрое сохранение</translation>
    </message>
    <message>
        <location filename="../MainUI.cpp" line="120"/>
        <source>PNG Files (*.png);;AllFiles (*)</source>
        <translation>PNG Файлы (*.png);;Все Файлы (*)</translation>
    </message>
</context>
<context>
    <name>XDGDesktopList</name>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="608"/>
        <source>Multimedia</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="609"/>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="610"/>
        <source>Education</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="611"/>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="612"/>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="613"/>
        <source>Network</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="614"/>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="615"/>
        <source>Science</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="616"/>
        <source>Settings</source>
        <translation type="unfinished">Настройки</translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="617"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="618"/>
        <source>Utility</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="619"/>
        <source>Wine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../core/libLumina/LuminaXDG.cpp" line="620"/>
        <source>Unsorted</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
